import Taro, { Component } from '@tarojs/taro';
import Authorize from '@components/authorize'
import './index.scss'
import { savePoint, updatePoint } from '@services/common'
import { connect } from '@tarojs/redux'
import { View, Text, Picker } from '@tarojs/components';
import { queryCustomerList } from '@services/person'
const iconImg = require('@assets/person/icon.png')

@connect(({ user, city }) => ({ user, city }))
export default class transactionCustomer extends Taro.Component {

  config = {
    navigationBarTitleText: '跟进客户'
  }


  state = {
    recordId: undefined, // 埋点ID
    customerList: [],
    inputValue: '',
    screenVisible: false,
    statusList: ['全部状态', '报备', '到访', '认筹'],
    statusIndex: -1,
    startArrivalDate: '',
    endArrivalDate: '',
    startReportDate : '',
    endReportDate: '',
  }

  componentWillUnmount() {
    const { recordId } = this.state
    recordId && updatePoint(recordId)
  }
  componentDidShow() {
    Taro.showLoading()
    this.loadList()

  }
  loadList() {
    const payload = {
      type: 'follow',
      pageNumber: 0,
      pageSize: 9999
    }
    queryCustomerList(payload.type, payload).then(res => {

      this.setState({
        customerList: res.records || []
      })
      Taro.hideLoading()
    })
  }


  changeInput = e => {
    this.setState({
      inputValue: e.detail.value
    })
  }
  searchBtn() {
    // const playload = {
    //   inputValue: this.state.inputValue
    // }
    this.filterCustomerList();
   
  }
  filterCustomerList(){

    const payload = {
      type: 'follow',
      pageNumber: 0,
      pageSize: 9999,
      status:this.state.statusIndex!=0?this.state.statusIndex:'',
      startArrivalDate:this.state.startArrivalDate,
      endArrivalDate: this.state.endArrivalDate,
      startReportDate : this.state.startReportDate,
      endReportDate: this.state.endReportDate,
    }
    queryCustomerList(payload.type, payload).then(res => {

      this.setState({
        customerList: res.records || []
      })
      Taro.hideLoading()
    })
  }
  saveBtn() {
    this.filterCustomerList();
    this.setState({
      screenVisible: false,
    })
  }
  screenShow() {
    this.setState({
      screenVisible: true,
    })
  }
  chooseStatus(item, inx) {
    this.setState({
      statusIndex: inx,
    })
    console.log(item, inx, "eeeeeeeeeeee")
  }
  onVisitDateChange = e => {
    this.setState({
      startArrivalDate: e.detail.value
    })
  }
  onVisitDateChange2 = e => {
    this.setState({
      endArrivalDate: e.detail.value
    })
  }
  onReportDateChange = e => {
    this.setState({
      startReportDate : e.detail.value
    })
  }
  onReportDateChange2 = e => {
    this.setState({
      endReportDate: e.detail.value
    })
  }
 
  cancelBtn() {
    this.setState({
      screenVisible: false,
      statusIndex: -1,
      startArrivalDate: '',
      endArrivalDate: '',
      startReportDate : '',
      endReportDate: '',
    })
  }
  toMyCustomer(customerId) {
    Taro.navigateTo({
      url: `/pages/person/customerAnalysis/myCustomer?customerId=`+customerId
    })
  }
  renderScreenBox() {
    const { statusList, statusIndex, startArrivalDate, endArrivalDate, startReportDate , endReportDate } = this.state
    return (
      <View className="mask">
        <View className="content">
          <View style="color:#333;font-size:14px">精准筛选</View>
          <View className="status-box">
            {
              statusList.map((item, index) => (
                <View key={index + 'status'} className={index == statusIndex ? 'checked' : 'status-item'} onClick={this.chooseStatus.bind(this, item, index)}>{item}</View>
              ))
            }
          </View>
          <View className="time-box">
            到访时间：
              <Picker mode='date' onChange={this.onVisitDateChange}>
              <View className='picker'>
                {startArrivalDate}
                {!startArrivalDate && <Text className="placeholder">起始时间</Text>}
              </View>
            </Picker>-<Picker mode='date' onChange={this.onVisitDateChange2}>
              <View className='picker'> 
                {endArrivalDate}
                {!endArrivalDate && <Text className="placeholder">结束时间</Text>}
              </View>
            </Picker>
          </View>
          <View className="time-box" style="margin-top:16px">
            报备时间：
              <Picker mode='date' onChange={this.onReportDateChange}>
              <View className='picker'>
                {startReportDate }
                {!startReportDate  && <Text className="placeholder">起始时间</Text>}
              </View>
            </Picker>-<Picker mode='date' onChange={this.onReportDateChange2}>
              <View className='picker'>
                {endReportDate}
                {!endReportDate && <Text className="placeholder">结束时间</Text>}
              </View>
            </Picker>
          </View>
          <View className="bottom-btn">
            <View className="save" onClick={this.saveBtn}>
              保存
            </View>
            <View className="cancel" onClick={this.cancelBtn}>
              取消
          </View>
            <View>
            </View>
          </View>
        </View>
      </View>
    )
  }

  render() {
    const { customerList, screenVisible } = this.state

    return (
      <View>
        <View className="top-screen" onClick={this.screenShow}>
          精准筛选<Image src={require('@assets/person/screen.png')} className="screen-img"></Image>
        </View>
        {screenVisible && this.renderScreenBox()}
        <View className="search-box">
          <Input class="input" placeholderClass='placeholder' autoFocus onInput={this.changeInput} placeholder="请输入用户名/手机号" />
          <Button className="btn" onClick={this.searchBtn} >搜索</Button>
        </View>
        <View style="padding:10px">
          {
            !customerList.length &&
            <View style="margin:50px auto;text-align:center;font-size:14px;color:#888">暂无跟进客户~</View>
          }
          {
            customerList.length &&
            customerList.map((item, index) => (
              <View class="item" key={index + 'customerList'} onClick={this.toMyCustomer.bind(this,item.customerId)}>
                <Image src={item.picture || require('@assets/default-avatar.png')} className='img'></Image>
                <View className="name">
                  {item.name}
                  {
                    item.sex == '1' && <View style={`margin-left:10px;background-image: url(${iconImg});background-size: 100%;background-position: 0px -20px;width: 18px;height: 18px;`}></View>
                  }
                  {
                    item.sex == '2' && <View style={`margin-left:10px;background-image: url(${iconImg});background-size: 100%;background-position: 0px 0px;width: 18px;height: 18px;`}></View>
                  }
                </View>
                <View className="phone">{item.phone}<View style={`background-image: url(${iconImg});background-size: 100%;background-position: 0px -44px;width: 22px;height: 22px;`}></View> </View>
                <View className="status">报备</View>
              </View>
            ))
          }
        </View>
      </View>
    )
  }
}