import Taro, { Component } from '@tarojs/taro';
import { AtTabs, AtTabsPane } from 'taro-ui'
import "taro-ui/dist/style/components/tabs.scss"
import { savePoint, updatePoint } from '@services/common'
import { getCustomerDetail, getVisitRecord, getActivityList, getFollowRecord } from '@services/person'
import { connect } from '@tarojs/redux'
import './index.scss'
import ActivityItem from './item'
import dayjs from 'dayjs'
const iconImg = require('@assets/person/icon.png')

@connect(({ user, city }) => ({ user, city }))
export default class myCustomer extends Taro.Component {

  config = {
    navigationBarTitleText: '我的客户'
  }

  state = {
    current: 0,
    recordId: undefined, // 埋点ID
    activityList: [],
    followVisible: false,
    baseVisible: false,
    message: '', //跟进内容
    desc: '', //客户描述
    selectorChecked: '',
    selector: ['美国', '中国', '巴西', '日本'],
    customerDetail: {},
    followRecord: []

  }

  componentWillUnmount() {

    const { recordId } = this.state
    recordId && updatePoint(recordId)
  }

  handleClick(value) {
    if (value == 1) {
      const { customerId } = this.$router.params
      const payload = {
        pageNumber: '0',
        pageSize: '10',
        customerId,
      }
      getVisitRecord(payload).then(res => {
        // this.setState({
        //   customerDetail: res || {}
        // })
      })
    } else if (value == 2) {
      const { customerId } = this.$router.params
      const payload = {
        pageNumber: '0',
        pageSize: '10',
        customerId,
      }
      getActivityList(payload).then(res => {
        this.setState({
          activityList: res.records || []
        })
      })
    } else if (value == 3) {
      const { customerId } = this.$router.params
      const payload = {
        pageNumber: '0',
        pageSize: '10',
        customerId,
      }
      getFollowRecord(payload).then(res => {
        console.log(res.records,"res")
        this.setState({
          followRecord: res.records 
        }, console.log(this.state.followRecord, "followRecord")
        )
      })
    }
    this.setState({
      current: value
    }, )
  }

  componentDidShow() {

    this.loadList()
  }
  loadList() {
    const { customerId } = this.$router.params
    getCustomerDetail(customerId).then(res => {
      this.setState({
        customerDetail: res || {}
      })
    })
  }
  handleItemClick(item) {
    // if (item.status == 0) {
    //   Taro.showToast({
    //     title: '当前活动已失效',
    //     icon: 'none'
    //   })
    // } else {
    switch (item.type) {
      case 'help':
        Taro.navigateTo({
          url: '/pages/activity/detail/assistance?id=' + item.id
        })
        return
      case 'group':
        Taro.navigateTo({
          url: '/pages/activity/detail/assemble?id=' + item.id
        })
        return
      default:
        Taro.navigateTo({
          url: '/pages/activity/detail/index?id=' + item.id
        })
        return
    }
    // }
  }
  addFollow() {
    this.setState({
      followVisible: true,
    })
  }
  saveBtn() {
    this.setState({
      followVisible: false,
    })
  }
  cancelBtn() {
    this.setState({
      followVisible: false,
    })
  }
  onTextareaChange(e) {
    this.setState({
      message: e.target.value
    })
  }
  renderFollowBox() {
    const { message } = this.state
    return (
      <View className="mask">
        <View className="content">
          <View style="display:flex;justify-content: space-between;">
            <View style="font-size:14px;color:#666">
              跟进内容：
            </View>
            <Textarea
              className="textarea"
              value={message}
              onInput={this.onTextareaChange}
              maxLength={150}
              placeholder='不超过150字'
            />
          </View>
          <View className="bottom-btn">
            <View className="save" onClick={this.saveBtn}>
              保存
            </View>
            <View className="cancel" onClick={this.cancelBtn}>
              取消
          </View>
          </View>
        </View>
      </View>
    )
  }
  perfectInformation() {
    this.setState({
      baseVisible: true,
    })
  }
  baseSaveBtn() {
    this.setState({
      baseVisible: false,
    })
  }
  baseCancelBtn() {
    this.setState({
      baseVisible: false,
    })
  }
  onBaseTextareaChange(e) {
    this.setState({
      desc: e.target.value
    })
  }
  onChange = e => {
    this.setState({
      selectorChecked: this.state.selector[e.detail.value]
    })
  }
  renderBaseBox() {
    const { desc, selector, selectorChecked } = this.state
    return (
      <View className="mask">
        <View className="base-con">
          <View className="con-item">
            <View style="font-size:14px;color:#666">
              物业类型：
            </View>
            <Input className="input" value={desc} onInput={this.onBaseTextareaChange} placeholder='' />
          </View>
          <View className="con-item">
            <View style="font-size:14px;color:#666">
              项目类型：
            </View>
            <View className="con-picker" >
              <View>
                <Picker mode='selector' range={selector} onChange={this.onChange}>
                  <View className='picker'>
                    当前选择：{selectorChecked}
                  </View>
                </Picker>
              </View>
              <View className="right-icon"></View>
            </View>
          </View>
          <View className="con-item">
            <View style="font-size:14px;color:#666">
              价格区间：
            </View>
            <Input className="input" value={desc} onInput={this.onBaseTextareaChange} placeholder='' />
          </View>
          <View style="display:flex;justify-content: space-between;">
            <View style="font-size:14px;color:#666">
              客户描述：
            </View>
            <Textarea
              className="textarea"
              value={desc}
              onInput={this.onBaseTextareaChange}
              maxLength={150}
              placeholder='不超过150字'
            />
          </View>
          <View className="bottom-btn">
            <View className="save" onClick={this.baseSaveBtn}>
              保存
            </View>
            <View className="cancel" onClick={this.baseCancelBtn}>
              取消
          </View>
          </View>
        </View>
      </View>
    )
  }


  render() {

    const tabList = [{ title: '基本信息' }, { title: '访问记录' }, { title: '活动信息' }, { title: '跟进记录' }]
    const { customerDetail, activityList, followRecord, followVisible, baseVisible } = this.state
    return (
      <View>
        {followVisible && this.renderFollowBox()}
        {baseVisible && this.renderBaseBox()}
        <View className="user_con">
          <Image className="bg" src={require('@assets/shop/background.jpg')} ></Image>
          <Image className="user__left__headimg" src={customerDetail.picture || require('@assets/default-avatar.png')} />
          <View className='user__left__name'>
            {customerDetail.name}
            {
              customerDetail.sex == '1' && <View style={`margin-left:10px;background-image: url(${iconImg});background-size: 100%;background-position: 0px -20px;width: 18px;height: 18px;`}></View>
            }
            {
              customerDetail.sex == '2' && <View style={`margin-left:10px;background-image: url(${iconImg});background-size: 100%;background-position: 0px 0px;width: 18px;height: 18px;`}></View>
            }
          </View>
          <View className='user__left__phone'>{customerDetail.phone}</View>
        </View>
        <AtTabs className="my-tab" current={this.state.current} tabList={tabList} onClick={this.handleClick.bind(this)}>
          <AtTabsPane current={this.state.current} index={0} >
            <View className="tab-pane1 pane">
              <View className="status">{customerDetail.status == 1 ? '报备' : customerDetail.status == 2 ? '到访' : customerDetail.status == 3 ? '认筹' : '签约'}</View>
              <View className="base-item">意向项目：<View className="con">{customerDetail.intention || '暂无'}</View></View>
              <View className="base-item">物业类型：<View className="con">{customerDetail.realtyManageType || '暂无'}</View></View>
              <View className="base-item">项目类型：<View className="con">{customerDetail.demandType || '暂无'}</View></View>
              <View className="base-item">价格区间：<View className="con">{customerDetail.priceRange || '暂无'}</View></View>
              <View className="base-item">客户描述：<View className="con">{customerDetail.describe || '暂无'}</View></View>
              <View className="btn" onClick={this.perfectInformation}>完善信息</View>
            </View>
          </AtTabsPane>
          <AtTabsPane current={this.state.current} index={1}>
            <View className="tab-pane2 pane">
              <View className="date">2019年11月11日</View>
              <View className="record-item"><View >查看项目详情：银城悦见山</View><View className="time">12:30:00</View> </View>
              <View className="record-item"><View >查看项目详情：银城悦见山</View><View className="time">12:30:00</View> </View>
              <View className="record-item"><View >查看项目详情：银城悦见山</View><View className="time">12:30:00</View> </View>
              <View className="date">2019年11月11日</View>
              <View className="record-item"><View >查看项目详情：银城悦见山</View><View className="time">12:30:00</View> </View>
              <View className="record-item"><View >查看项目详情：银城悦见山</View><View className="time">12:30:00</View> </View>
              <View className="record-item"><View >查看项目详情：银城悦见山</View><View className="time">12:30:00</View> </View>
            </View>
          </AtTabsPane>
          <AtTabsPane current={this.state.current} index={2}>
            <View className="tab-pane3 pane">
              {activityList.length > 0 &&
                activityList.map(item => (
                  <ActivityItem
                    data={item}
                    key={item.id}
                    onClick={this.handleItemClick}>
                  </ActivityItem>
                ))
              }
            </View>
          </AtTabsPane>
          <AtTabsPane current={this.state.current} index={3}>
            <View style="padding:10px 20px 120px 20px">
              {/* {followRecord.map(item => {
                <View style=" display: flex;justify-content: space-between;align-items: center;color: #333;font-size: 16px;"> */}
                  {/* <View style=" display: flex;align-items: center;"><View style="width:8px;height:8px;margin-right:10px;display:inline-block;background:rgba(246,182,29,1);border-radius: 50%;"></View>{item.recordType}</View>
                    <View classNam="time" style=" font-size: 13px;color: #999;">{dayjs(item.createDate).format('YYYY-MM-DD') || ''}</View> */}
                {/* </View>
              })
              } */}
              <View className="btn" onClick={this.addFollow}>添加跟进</View>
            </View>

          </AtTabsPane>
        </AtTabs>
      </View>
    )
  }
}